@@ -11,7 +11,7 @@ automatically handles authentication by exchanging your API key for a JWT token
 The Client class offers methods for:
 - Authentication and session management
 - Making API requests with automatic token refresh
-- Accessing AI capabilities: chat completions, text completions, embeddings, and image generation
+- Accessing AI capabilities: chat completions, text completions, embeddings, image generation, and text-to-speech
 - Retrieving information about available providers and models
 - Monitoring usage statistics and credit consumption
 
@@ -34,6 +34,9 @@ Usage example:
     # Generate text embeddings
     embeddings = client.embeddings("This is a sample text", model="openai/text-embedding-ada-002")
 
+    # Generate text-to-speech audio
+    audio = client.text_to_speech("Hello, welcome to IndoxRouter!", model="openai/tts-1", voice="alloy")
+
     # Clean up resources when done
     client.close()
     ```
@@ -72,10 +75,12 @@ from .constants import (
     DEFAULT_MODEL,
     DEFAULT_EMBEDDING_MODEL,
     DEFAULT_IMAGE_MODEL,
+    DEFAULT_TTS_MODEL,
     CHAT_ENDPOINT,
     COMPLETION_ENDPOINT,
     EMBEDDING_ENDPOINT,
     IMAGE_ENDPOINT,
+    TTS_ENDPOINT,
     MODEL_ENDPOINT,
     USAGE_ENDPOINT,
     USE_COOKIES,
@@ -93,6 +98,7 @@ class Client:
         self,
         api_key: Optional[str] = None,
         timeout: int = DEFAULT_TIMEOUT,
+        base_url: Optional[str] = None,
     ):
         """
         Initialize the client.
@@ -101,6 +107,7 @@ class Client:
             api_key: API key for authentication. If not provided, the client will look for the
                 INDOX_ROUTER_API_KEY environment variable.
             timeout: Request timeout in seconds.
+            base_url: Base URL for the API. If not provided, the client will use the default URL.
         """
 
         use_cookies = USE_COOKIES
@@ -110,7 +117,11 @@ class Client:
                 "API key must be provided either as an argument or as the INDOX_ROUTER_API_KEY environment variable."
             )
 
-        self.base_url = DEFAULT_BASE_URL
+        self.base_url = base_url if base_url is not None else DEFAULT_BASE_URL
+
+        if self.base_url.endswith("/"):
+            self.base_url = self.base_url.rstrip("/")
+
         self.timeout = timeout
         self.use_cookies = use_cookies
         self.session = requests.Session()
@@ -399,6 +410,48 @@ class Client:
         # is having issues with JSON formatted model strings
         return model
 
+    def _format_image_size_for_provider(
+        self, size: str, provider: str, model: str
+    ) -> str:
+        """
+        Format the image size parameter based on the provider's requirements.
+
+        Google requires aspect ratios like "1:1", "4:3", etc. while OpenAI uses pixel dimensions
+        like "1024x1024", "512x512", etc.
+
+        Args:
+            size: The size parameter (e.g., "1024x1024")
+            provider: The provider name (e.g., "google", "openai")
+            model: The model name
+
+        Returns:
+            Formatted size parameter appropriate for the provider
+        """
+        if provider.lower() == "google":
+            # Google uses aspect ratios instead of pixel dimensions
+            # Convert common pixel dimensions to aspect ratios
+            size_to_aspect_ratio = {
+                "1024x1024": "1:1",
+                "512x512": "1:1",
+                "256x256": "1:1",
+                "1024x768": "4:3",
+                "768x1024": "3:4",
+                "1024x1536": "2:3",
+                "1536x1024": "3:2",
+                "1792x1024": "16:9",
+                "1024x1792": "9:16",
+            }
+
+            # Check if size is already in aspect ratio format (contains a colon)
+            if ":" in size:
+                return size
+
+            # Convert to aspect ratio if we have a mapping, otherwise use default 1:1
+            return size_to_aspect_ratio.get(size, "1:1")
+
+        # For other providers, return the original size
+        return size
+
     def chat(
         self,
         messages: List[Dict[str, str]],
@@ -531,10 +584,10 @@ class Client:
         self,
         prompt: str,
         model: str = DEFAULT_IMAGE_MODEL,
-        size: str = "1024x1024",
-        n: int = 1,
-        quality: str = "standard",
-        style: str = "vivid",
+        size: Optional[str] = None,
+        n: Optional[int] = None,
+        quality: Optional[str] = None,
+        style: Optional[str] = None,
         # Standard parameters
         response_format: Optional[str] = None,
         user: Optional[str] = None,
@@ -555,6 +608,8 @@ class Client:
         output_mime_type: Optional[str] = None,
         add_watermark: Optional[bool] = None,
         enhance_prompt: Optional[bool] = None,
+        # Google-specific direct parameters
+        aspect_ratio: Optional[str] = None,
         **kwargs,
     ) -> Dict[str, Any]:
         """
@@ -563,10 +618,13 @@ class Client:
         Args:
             prompt: Text prompt
             model: Model to use in the format "provider/model" (e.g., "openai/dall-e-3", "google/imagen-3.0-generate-002")
-            size: Image size (e.g., "1024x1024")
+
+            # Provider-specific parameters - will only be included if explicitly provided
+            # Note: Different providers support different parameters
+            size: Image size - For OpenAI: "1024x1024", "512x512", etc. For Google: use aspect_ratio instead
             n: Number of images to generate
-            quality: Image quality (e.g., "standard", "hd")
-            style: Image style (e.g., "vivid", "natural")
+            quality: Image quality (e.g., "standard", "hd") - supported by some providers
+            style: Image style (e.g., "vivid", "natural") - supported by some providers
 
             # Standard parameters
             response_format: Format of the response - "url" or "b64_json"
@@ -590,6 +648,7 @@ class Client:
             output_mime_type: MIME type of the generated image
             add_watermark: Whether to add a watermark to the generated images
             enhance_prompt: Whether to use prompt rewriting logic
+            aspect_ratio: Aspect ratio for Google models (e.g., "1:1", "16:9") - preferred over size
 
             **kwargs: Additional parameters to pass to the API
 
@@ -599,25 +658,68 @@ class Client:
         # Format the model string
         formatted_model = self._format_model_string(model)
 
+        # Extract provider and model name from model string if present
+        provider = "openai"  # Default provider
+        model_name = model
+        if "/" in model:
+            provider, model_name = model.split("/", 1)
+
         # Filter out problematic parameters
         filtered_kwargs = {}
         for key, value in kwargs.items():
             if key not in ["return_generator"]:  # List of parameters to exclude
                 filtered_kwargs[key] = value
 
-        # Create the base request data
+        # Create the base request data with only the required parameters
         data = {
             "prompt": prompt,
             "model": formatted_model,
-            "n": n,
-            "size": size,
-            "quality": quality,
-            "style": style,
         }
 
+        # Add optional parameters only if they are explicitly provided
+        if n is not None:
+            data["n"] = n
+
+        # Handle size/aspect_ratio parameters based on provider
+        if provider.lower() == "google":
+            # For Google, use aspect_ratio instead of size
+            if aspect_ratio is not None:
+                # Google's imagen-3 has specific supported aspect ratios
+                if model_name == "imagen-3.0-generate-002" and aspect_ratio not in [
+                    "1:1",
+                    "3:4",
+                    "4:3",
+                    "9:16",
+                    "16:9",
+                ]:
+                    aspect_ratio = "1:1"  # Default to 1:1 if not supported
+                data["aspect_ratio"] = aspect_ratio
+            elif size is not None:
+                # Convert size to aspect_ratio
+                formatted_size = self._format_image_size_for_provider(
+                    size, provider, model_name
+                )
+                data["aspect_ratio"] = formatted_size
+            else:
+                # Default aspect_ratio for Google
+                data["aspect_ratio"] = "1:1"
+        elif provider.lower() == "xai":
+            # xAI doesn't support size parameter - do not include it
+            pass
+        elif size is not None and provider.lower() != "xai":
+            # For other providers (like OpenAI), use size as is
+            data["size"] = size
+
+        if quality is not None:
+            data["quality"] = quality
+        if style is not None:
+            data["style"] = style
+
         # Add standard parameters if provided
         if response_format is not None:
+            # Only add response_format if explicitly provided by the user
             data["response_format"] = response_format
+
         if user is not None:
             data["user"] = user
 
@@ -659,8 +761,161 @@ class Client:
         if filtered_kwargs:
             data["additional_params"] = filtered_kwargs
 
+        # Special case handling for specific models and providers
+        # Only include parameters supported by each model based on their JSON definitions
+        if provider.lower() == "openai" and "gpt-image" in model_name.lower():
+            # For OpenAI's gpt-image models, don't automatically add response_format
+            if "response_format" in data and response_format is None:
+                del data["response_format"]
+
+        if provider.lower() == "xai" and "grok-2-image" in model_name.lower():
+            # For xAI's grok-2-image models, ensure size is not included
+            if "size" in data:
+                del data["size"]
+
+        # Clean up any parameters that shouldn't be sent to specific providers
+        # This ensures we only send parameters that each provider supports
+        supported_params = self._get_supported_parameters_for_model(
+            provider, model_name
+        )
+        if supported_params:
+            for param in list(data.keys()):
+                if param not in ["prompt", "model"] and param not in supported_params:
+                    del data[param]
+
         return self._request("POST", IMAGE_ENDPOINT, data)
 
+    def text_to_speech(
+        self,
+        input: str,
+        model: str = DEFAULT_TTS_MODEL,
+        voice: Optional[str] = None,
+        response_format: Optional[str] = None,
+        speed: Optional[float] = None,
+        instructions: Optional[str] = None,
+        **kwargs,
+    ) -> Dict[str, Any]:
+        """
+        Generate audio from text using text-to-speech models.
+
+        Args:
+            input: The text to generate audio for
+            model: Model to use in the format "provider/model" (e.g., "openai/tts-1")
+            voice: Voice to use for the audio generation (provider-specific)
+            response_format: Format of the audio response (e.g., "mp3", "opus", "aac", "flac")
+            speed: Speed of the generated audio (0.25 to 4.0)
+            instructions: Optional instructions for the TTS generation
+            **kwargs: Additional parameters to pass to the API
+
+        Returns:
+            Response data with audio content
+
+        Examples:
+            Basic usage:
+                response = client.text_to_speech("Hello, world!")
+
+            With specific voice and format:
+                response = client.text_to_speech(
+                    "Hello, world!",
+                    model="openai/tts-1",
+                    voice="alloy",
+                    response_format="mp3",
+                    speed=1.0
+                )
+
+            For different providers (when available):
+                response = client.text_to_speech(
+                    "Hello, world!",
+                    model="provider/model-name",
+                    voice="provider-specific-voice"
+                )
+        """
+        # Format the model string
+        formatted_model = self._format_model_string(model)
+
+        # Filter out problematic parameters
+        filtered_kwargs = {}
+        for key, value in kwargs.items():
+            if key not in ["return_generator"]:  # List of parameters to exclude
+                filtered_kwargs[key] = value
+
+        # Create the base request data with required parameters
+        data = {
+            "input": input,
+            "model": formatted_model,
+        }
+
+        # Add optional parameters only if they are explicitly provided
+        if voice is not None:
+            data["voice"] = voice
+        if response_format is not None:
+            data["response_format"] = response_format
+        if speed is not None:
+            data["speed"] = speed
+        if instructions is not None and instructions.strip():
+            data["instructions"] = instructions
+
+        # Add any additional parameters from kwargs
+        if filtered_kwargs:
+            data["additional_params"] = filtered_kwargs
+
+        return self._request("POST", TTS_ENDPOINT, data)
+
+    def _get_supported_parameters_for_model(
+        self, provider: str, model_name: str
+    ) -> List[str]:
+        """
+        Get the list of supported parameters for a specific model.
+        This helps avoid sending unsupported parameters to providers.
+
+        Args:
+            provider: The provider name (e.g., 'openai', 'google', 'xai')
+            model_name: The model name (e.g., 'gpt-image-1', 'imagen-3.0-generate-002')
+
+        Returns:
+            List of parameter names supported by the model
+        """
+        # Define supported parameters for specific models
+        if provider.lower() == "openai" and "gpt-image" in model_name.lower():
+            return [
+                "prompt",
+                "size",
+                "quality",
+                "n",
+                "user",
+                "background",
+                "moderation",
+                "output_compression",
+                "output_format",
+                "style",
+            ]
+
+        elif provider.lower() == "google" and "imagen" in model_name.lower():
+            return [
+                "prompt",
+                "n",
+                "negative_prompt",
+                "aspect_ratio",
+                "guidance_scale",
+                "seed",
+                "safety_filter_level",
+                "person_generation",
+                "include_safety_attributes",
+                "include_rai_reason",
+                "language",
+                "output_mime_type",
+                "output_compression_quality",
+                "add_watermark",
+                "enhance_prompt",
+                "response_format",
+            ]
+
+        elif provider.lower() == "xai" and "grok-2-image" in model_name.lower():
+            return ["prompt", "n", "response_format"]
+
+        # Default case - allow all parameters
+        return []
+
     def models(self, provider: Optional[str] = None) -> Dict[str, Any]:
         """
         Get available models.
