@@ -13,6 +13,7 @@ USE_COOKIES = True  # Always use cookie-based authentication
 DEFAULT_MODEL = "openai/gpt-4o-mini"
 DEFAULT_EMBEDDING_MODEL = "openai/text-embedding-3-small"
 DEFAULT_IMAGE_MODEL = "openai/dall-e-3"
+DEFAULT_TTS_MODEL = "openai/tts-1"
 GOOGLE_IMAGE_MODEL = "google/imagen-3.0-generate-002"
 XAI_IMAGE_MODEL = "xai/grok-2-image"
 XAI_IMAGE_LATEST_MODEL = "xai/grok-2-image-latest"
@@ -23,6 +24,7 @@ CHAT_ENDPOINT = "chat/completions"
 COMPLETION_ENDPOINT = "completions"
 EMBEDDING_ENDPOINT = "embeddings"
 IMAGE_ENDPOINT = "images/generations"
+TTS_ENDPOINT = "tts/generations"
 MODEL_ENDPOINT = "models"
 USAGE_ENDPOINT = "user/usage"
 
